@@ -3,13 +3,13 @@ package MooX::File::ConfigDir;
 use strict;
 use warnings;
 
-our $VERSION = "0.002";
+our $VERSION = "0.003";
 
-use namespace::autoclean;
 use Scalar::Util qw(blessed);
+use File::ConfigDir ();
+use namespace::clean;
 
 use Moo::Role;
-use File::ConfigDir ();
 
 has 'config_identifier' => (
                              is => 'lazy',
@@ -206,7 +206,7 @@ L<http://search.cpan.org/dist/MooX-File-ConfigDir/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013 Jens Rehsack.
+Copyright 2013-2014 Jens Rehsack.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
